//============================================================================================================
// Microsoft Updater Application Block for .NET
//  http://msdn.microsoft.com/library/en-us/dnbda/html/updater.asp
//	
// FileManifest.cs
//
// Contains the implementation of the file information in the manifest.
// 
// For more information see the Updater Application Block Implementation Overview. 
// 
//============================================================================================================
// Copyright  Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//============================================================================================================

using System;
using System.Xml;
using System.Xml.Serialization;

namespace Microsoft.ApplicationBlocks.Mobile.Updater
{
    /// <summary>
    /// Defines the information of a file in the manifest.
    /// </summary>
    public class FileManifest
    {
        #region Private members

        /// <summary>
        /// Internal manifestFile
        /// </summary>
        Xsd.ManifestFile file;

        #endregion

        #region Constructor

        /// <summary>
        /// Creates a new FileManifest with the desrialized manifest file information.
        /// </summary>
        /// <param name="file">The FileManifest instance.</param>
        public FileManifest(Xsd.ManifestFile file)
        {
            this.file = file;
        }

        /// <summary>
        /// Default contructor
        /// </summary>
        public FileManifest()
        {
        }

        #endregion

        #region Public properties
        /// <summary>
        /// Manifest file
        /// </summary>
        public Xsd.ManifestFile ManifestFile
        {
            get { return file; }
            set { file = value; }
        }

        /// <summary>
        /// The source location of the file.
        /// </summary>
        [XmlIgnore]
        public string Source
        {
            get { return file.Source; }
        }

        /// <summary>
        /// Whether the file is transient or not.
        /// </summary>
        [XmlIgnore]
        public bool Transient
        {
            get
            {
                return file.Transient == Xsd.YesNoBoolType.True
                    || file.Transient == Xsd.YesNoBoolType.Yes;
            }
        }

        /// <summary>
        /// The calculated hash for the file.
        /// </summary>
        [XmlIgnore]
        public string Hash
        {
            get { return file.Hash; }
        }

        /// <summary>
        /// The attributes specified for the file.
        /// </summary>
        [XmlIgnore]
        public XmlAttribute[] Attributes
        {
            get { return file.AnyAttr; }
        }
        #endregion
    }
}
