//============================================================================================================
// Microsoft Updater Application Block for .NET
//  http://msdn.microsoft.com/library/en-us/dnbda/html/updater.asp
//	
// StateBag.cs
//
// Contains the implementation of a state bag.
// 
// For more information see the Updater Application Block Implementation Overview. 
// 
//============================================================================================================
// Copyright  Microsoft Corporation.  All rights reserved.
// THIS CODE AND INFORMATION IS PROVIDED "AS IS" WITHOUT WARRANTY
// OF ANY KIND, EITHER EXPRESSED OR IMPLIED, INCLUDING BUT NOT
// LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
// FITNESS FOR A PARTICULAR PURPOSE.
//============================================================================================================

using System;
using System.Collections.Generic;
using System.Xml;
using System.Xml.Serialization;

namespace Microsoft.ApplicationBlocks.Mobile.Updater
{
    public class StateBag :
        Dictionary<string, object>,
        IXmlSerializable
    {
        #region Constructor
        /// <summary>
        /// Default constructor.
        /// </summary>
        public StateBag()
        {
        }
        #endregion

        public System.Xml.Schema.XmlSchema GetSchema()
        {
            return null;
        }

        public void ReadXml(XmlReader reader)
        {
            reader.Read();
            reader.ReadStartElement("dictionary");
            XmlSerializer xmlObjectSerializer = new XmlSerializer(typeof(object));

            while (reader.NodeType != XmlNodeType.EndElement)
            {
                reader.ReadStartElement("item");
                string key = reader.ReadElementString("key");
                object value = xmlObjectSerializer.Deserialize(reader);
                reader.ReadEndElement();
                reader.MoveToContent();
                base.Add(key, value);
            }

            reader.ReadEndElement();
            reader.ReadEndElement();
        }

        public void WriteXml(XmlWriter writer)
        {
            writer.WriteStartElement("dictionary");
            XmlSerializer xmlObjectSerializer = new XmlSerializer(typeof(object));

            foreach (String key in base.Keys)
            {
                object value = base[key];
                writer.WriteStartElement("item");
                writer.WriteElementString("key", key);
                xmlObjectSerializer.Serialize(writer, value);
                writer.WriteEndElement();
            }

            writer.WriteEndElement();
        }
    }
}
