﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.Text;
using Microsoft.Practices.Mobile.ContainerModel;

namespace EventAggregationQuickStart
{
    /// <summary>
    /// Service exposed by the shell that allows modules to publish tasks 
    /// they provide.
    /// The service exposes IEnumerable so that users can 'foreach' through the
    /// collection.
    /// </summary>
    public interface ITaskService
    {
        /// <summary>
        /// Here we register an IView type, giving it a name and an icon.
        /// </summary>
        void Register<TPresenter>(string taskName)
            where TPresenter : IModule;

        /// <summary>
        /// Executes the task with the given name.
        /// </summary>
        void Execute(string taskName);

        /// <summary>
        /// Lists the registered Tasks
        /// </summary>
        Dictionary<string, TaskDetail> Tasks { get; }

    }

    public class TaskDetail
    {
        public Action<Container> Action { get; set; }
    }
}
